==> order-center-domain-3.2.2-CLOUD-DEV-20240711.022813-28-sources.jar: com/tydic/dyc/oc/model/saleorder/sub/UocSaleOrderItem.java <==
package com.tydic.dyc.oc.model.saleorder.sub;

import com.tydic.dyc.base.bo.BaseExtendBo;
import com.tydic.dyc.oc.model.order.sub.UocOrderAccessory;
import com.tydic.dyc.oc.model.order.sub.UocOrderAgreement;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtCrossBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocCreateOrderServiceReqAccessoryBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocOrderPlanBO;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocSaleOrderItem
 * 说明:销售订单明细
 * 时间:2022-02-21 19:11
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper = false)
public class UocSaleOrderItem extends BaseExtendBo {
    private static final long serialVersionUID = -1930014495446916868L;

    //订单id")
    private Long orderId;

    //销售明细id")
    private Long saleOrderItemId;

    //销售单id")
    private Long saleOrderId;

    //订单明细id")
    private Long orderItemId;

    //sap订单编号
    private String sapOrderNo;

    //sap 订单明细编号
    private String sapOrderItemNo;

    //比选单号")
    private String cmpOrderNo;

    //明细类型             1 商品sku             2 物资             3 项目")
    private Integer itemType;

    //商品来源，区分电商、协议、无协议", required = true, valArg = "商品来源")
    private Integer skuSource;

    //明细类型翻译")
    private String itemTypeStr;

    //明细状态")
    private String saleItemState;

    //发货单明细状态")
    private String shipItemState;

    //单品ID")
    private String skuId;

    //单品编码")
    private String skuCode;

    //单品名称")
    private String skuName;

    //商品id")
    private String commodityId;

    //商品名称")
    private String commodityName;

    //商品类型id")
    private String commodityTypeId;

    //商品类型名称")
    private String commodityTypeName;

    //供应商ID")
    private String supplierId;

    //店铺ID")
    private String supplierShopId;

    //采购金额")
    private BigDecimal purchasePrice;

    //销售金额")
    private BigDecimal salePrice;

    //总销售金额")
    private BigDecimal totalSaleFee;

    //采购数量")
    private BigDecimal purchaseCount;

    //运费")
    private BigDecimal transFee;

    //采购金额")
    private BigDecimal purchaseFee;

    //应付金额")
    private BigDecimal payFee;

    //积分优惠金额")
    private BigDecimal integralDisFee;

    //活动优惠金额")
    private BigDecimal actDisFee;

    //其它优惠金额")
    private BigDecimal otherDisFee;

    //实付金额")
    private BigDecimal usedFee;

    //实付积分")
    private BigDecimal usedIntegral;

    //币种")
    private String currencyType;

    //税金")
    private BigDecimal taxPrice;

    //税率")
    private BigDecimal tax;

    //税务编码")
    private String taxId;

    //预计发货时间")
    private Date preSendTime;

    //预计交货时间")
    private Date preOfferTime;

    //计量单位")
    private String unitName;

    //结算计量单位")
    private String settleUnit;

    //售后在途数量")
    private BigDecimal afterServingCount;

    //外部电商主订单id")
    private String lmOrderId;

    //外部电商子订单id")
    private String lmSubOrderId;

    //到货周期")
    private String arrivalTime;

    //加价率")
    private Double markUpRate;

    //商品服务费 ")
    private String serPrice;

    //京能新增参数开始  ///////////////////////////
    /**
     * 计划ID
     */
    private String planId;
    /**
     * 计划编号
     */
    private String planNo;
    /**
     * 计划明细ID
     */
    private String planItemId;
    /**
     * 计划明细编号
     */
    private String planItemNo;
    /**
     * 计划来源1SAP;2电商平台
     */
    private Integer planSource;
    /**
     * 计划单位
     */
    private String planUnit;
    /**
     * 单位转换倍率
     */
    private BigDecimal planConversionRate;
    //京能新增参数开始  ///////////////////////////

    //协议id")
    private String agreementId;

    //协议编号")
    private String agreementNo;

    //协议模式 1：平台协议 2：单位协议")
    private Integer agreementCode;

    //协议明细编号")
    private String agreementIdItemNo;

    //创建时间")
    private Date createTime;

    //创建工号")
    private String createOperId;

    //更新时间")
    private Date updateTime;

    //更新工号")
    private String updateOperId;

    //备注")
    private String remark;

    //超验百分比，下单时保存（协议、无协议）")
    private Integer inspectionExcessPercent;

    //销售单明细扩展")
    private List<UocSaleItemMap> saleItemMapList;

    //销售单明细横向扩展数据")
    private UocBaseExtCrossBo extCrossBo;

    //sku物料ID")
    private String skuMaterialId;

    //sku物料编码")
    private String skuMaterialCode;

    //sku外部单品id")
    private String skuExtSkuId;

    //sku品牌id")
    private Long skuBrandId;

    //单品品牌名称")
    private String skuBrandName;

    //sku明细id")
    private String skuItemId;

    //sku物料名称")
    private String skuMaterialName;

    //sku物料类型名称")
    private String skuMaterialTypeName;

    //sku物料类型id")
    private String skuMaterialTypeId;

    //型号")
    private String model;

    //规格")
    private String spec;

    //材质")
    private String texture;

    //图号")
    private String figure;

    //一级类目")
    private Long l1Catalog;

    //二级类目")
    private Long l2Catalog;

    //三级类目")
    private Long l3Catalog;

    //一级类目名称")
    private String l1CatalogName;

    //二级类目名称")
    private String l2CatalogName;

    //三级类目名称")
    private String l3CatalogName;

    //退货时间，空代表不支持")
    private Integer rejectAllowDate;

    //换货时间，空代表不支持")
    private Integer exchangeAllowDate;

    //维修时间，空代表不支持")
    private Integer maintainAllowDate;

    //sku单品主图url")
    private String skuMainPicUrl;

    //是否存在超验 0否 1是")
    private Integer inspSuper;

    //到货时间")
    private Date arriveTime;

    //发货数量")
    private BigDecimal sendCount;

    //验收数量")
    private BigDecimal acceptanceCount;

    //退货数量")
    private BigDecimal returnCount;

    //到货数量")
    private BigDecimal arriveCount;

    //拒收数量")
    private BigDecimal refuseCount;

    //异常变更在途数量")
    private BigDecimal chngingCount;

    //订单IDList")
    private List<Long> orderIdList;


    //销售单IdList")
    private List<Long> saleOrderItemsIdList;

    //销售金额")
    private BigDecimal saleFee;

    //裸价")
    private BigDecimal nakedPrice;

    //超验数量")
    private BigDecimal inspSuperCount;

    //商品编码
    //商品编码")
    private String commodityCode;

    /**
     * 未比选原因
     */
    private String noCmpReason;
    /**
     * 供货周期
     */
    private String deliveryTimeDate;
    /**
     * 供应商+结算模式key
     */
    private String supplierIdModelSettelKey;
    /**
     * 拒收评价标识
     */
    private String evaSign;

    /**
     * 协议bo，协议商品必传（根据协议id是否为空来判断）
     */
    private UocOrderAgreement agrBo;
    /**
     * 计量单位位数
     */
    private String unitDigit;

    /**
     * 商品支持售后返回方式
     */
    private List<Integer> serverReturnTypeList;

    //商品关联计划明细列表
    private List<UocOrderPlanBO> orderPlanBOList;


    /**
     * 议价单id
     */
    private Long bargainingId;
    /**
     * 议价单编码
     */
    private String bargainingNo;

    /**
     * 铺货单位ID
     */
    private String managementOrgId;
    /**
     * 铺货单位名称
     */
    private String managementOrgName;
    /**
     * 协议价格明细执行时间
     */
    private Date agrItemActiveTime;
    /**
     * 协议价格明细创建时间
     */
    private Date agrItemCreateTime;
    /**
     * 协议价格明细不含税单价
     */
    private BigDecimal agrItemNoTaxPrice;
    /**
     * 订单附件信息
     */
    private List<UocOrderAccessory> attachBos;
}

==> order-center-domain-3.2.3-CLOUD-DEV-20241122.031858-21-sources.jar: com/tydic/dyc/oc/model/saleorder/sub/UocSaleOrderItem.java <==
package com.tydic.dyc.oc.model.saleorder.sub;

import com.tydic.dyc.base.bo.BaseExtendBo;
import com.tydic.dyc.oc.model.order.sub.UocOrderAgreement;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtCrossBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocOrderPlanBO;

import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocSaleOrderItem
 * 说明:销售订单明细
 * 时间:2022-02-21 19:11
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocSaleOrderItem extends BaseExtendBo {
    private static final long serialVersionUID = -1930014495446916868L;

    //订单id")
    private Long orderId;

    //销售明细id")
    private Long saleOrderItemId;

    //销售单id")
    private Long saleOrderId;

    //订单明细id")
    private Long orderItemId;

    //比选单号")
    private String cmpOrderNo;

    //明细类型             1 商品sku             2 物资             3 项目")
    private Integer itemType;

    //商品来源，区分电商、协议、无协议", required = true, valArg = "商品来源")
    private Integer skuSource;

    //明细类型翻译")
    private String itemTypeStr;

    //明细状态")
    private String saleItemState;

    //发货单明细状态")
    private String shipItemState;

    //单品ID")
    private String skuId;

    //单品编码")
    private String skuCode;

    //单品名称")
    private String skuName;

    //商品id")
    private String commodityId;

    //商品名称")
    private String commodityName;

    //商品类型id")
    private String commodityTypeId;

    //商品类型名称")
    private String commodityTypeName;

    //供应商ID")
    private String supplierId;

    //店铺ID")
    private String supplierShopId;

    //采购金额")
    private BigDecimal purchasePrice;

    //销售金额")
    private BigDecimal salePrice;

    //总销售金额")
    private BigDecimal totalSaleFee;

    //采购数量")
    private BigDecimal purchaseCount;

    //运费")
    private BigDecimal transFee;

    //采购金额")
    private BigDecimal purchaseFee;

    //应付金额")
    private BigDecimal payFee;

    //积分优惠金额")
    private BigDecimal integralDisFee;

    //活动优惠金额")
    private BigDecimal actDisFee;

    //其它优惠金额")
    private BigDecimal otherDisFee;

    //实付金额")
    private BigDecimal usedFee;

    //实付积分")
    private BigDecimal usedIntegral;

    //币种")
    private String currencyType;

    //税金")
    private BigDecimal taxPrice;

    //税率")
    private BigDecimal tax;

    //税务编码")
    private String taxId;

    //预计发货时间")
    private Date preSendTime;

    //预计交货时间")
    private Date preOfferTime;

    //计量单位")
    private String unitName;

    //结算计量单位")
    private String settleUnit;

    //售后在途数量")
    private BigDecimal afterServingCount;

    //外部电商主订单id")
    private String lmOrderId;

    //外部电商子订单id")
    private String lmSubOrderId;

    //到货周期")
    private String arrivalTime;

    //加价率")
    private Double markUpRate;

    //商品服务费 ")
    private String serPrice;

    //计划id")
    private String planId;

    //计划明细id")
    private String planItemId;

    //计划编号")
    private String planNo;

    //计划明细编号")
    private String planItemNo;

    //协议id")
    private String agreementId;

    //协议编号")
    private String agreementNo;

    //协议模式 1：平台协议 2：单位协议")
    private Integer agreementCode;

    //协议明细编号")
    private String agreementIdItemNo;

    //创建时间")
    private Date createTime;

    //创建工号")
    private String createOperId;

    //更新时间")
    private Date updateTime;

    //更新工号")
    private String updateOperId;

    //备注")
    private String remark;

    //超验百分比，下单时保存（协议、无协议）")
    private Integer inspectionExcessPercent;

    //销售单明细扩展")
    private List<UocSaleItemMap> saleItemMapList;

    //销售单明细横向扩展数据")
    private UocBaseExtCrossBo extCrossBo;

    //sku物料ID")
    private String skuMaterialId;

    //sku物料编码")
    private String skuMaterialCode;

    //sku外部单品id")
    private String skuExtSkuId;

    //sku品牌id")
    private Long skuBrandId;

    //单品品牌名称")
    private String skuBrandName;

    //sku明细id")
    private String skuItemId;

    //sku物料名称")
    private String skuMaterialName;

    //sku物料类型名称")
    private String skuMaterialTypeName;

    //sku物料类型id")
    private String skuMaterialTypeId;

    //型号")
    private String model;

    //规格")
    private String spec;

    //材质")
    private String texture;

    //图号")
    private String figure;

    //一级类目")
    private String l1Catalog;

    //二级类目")
    private String l2Catalog;

    //三级类目")
    private String l3Catalog;

    //一级类目名称")
    private String l1CatalogName;

    //二级类目名称")
    private String l2CatalogName;

    //三级类目名称")
    private String l3CatalogName;

    //退货时间，空代表不支持")
    private Integer rejectAllowDate;

    //换货时间，空代表不支持")
    private Integer exchangeAllowDate;

    //维修时间，空代表不支持")
    private Integer maintainAllowDate;

    //sku单品主图url")
    private String skuMainPicUrl;

    //是否存在超验 0否 1是")
    private Integer inspSuper;

    //到货时间")
    private Date arriveTime;

    //发货数量")
    private BigDecimal sendCount;

    //验收数量")
    private BigDecimal acceptanceCount;

    //退货数量")
    private BigDecimal returnCount;

    //到货数量")
    private BigDecimal arriveCount;

    //拒收数量")
    private BigDecimal refuseCount;

    //异常变更在途数量")
    private BigDecimal chngingCount;

    //订单IDList")
    private List<Long> orderIdList;


    //销售单IdList")
    private List<Long> saleOrderItemsIdList;

    //销售金额")
    private BigDecimal saleFee;

    //裸价")
    private BigDecimal nakedPrice;

    //超验数量")
    private BigDecimal inspSuperCount;

    //商品编码
    //商品编码")
    private String commodityCode;

    /**
     * 未比选原因
     */
    private String noCmpReason;
    /**
     * 供货周期
     */
    private String deliveryTimeDate;
    /**
     * 供应商+结算模式key
     */
    private String supplierIdModelSettelKey;
    /**
     * 拒收评价标识
     */
    private String evaSign;

    /**
     * 协议bo，协议商品必传（根据协议id是否为空来判断）
     */
    private UocOrderAgreement agrBo;
    /**
     * 计量单位位数
     */
    private String unitDigit;

    /**
     * 商品支持售后返回方式
     */
    private List<Integer> serverReturnTypeList;

    //商品关联计划明细列表
    private List<UocOrderPlanBO> orderPlanBOList;


    /**
     * 议价单id
     */
    private Long bargainingId;
    /**
     * 议价单编码
     */
    private String bargainingNo;

    /**
     * 铺货单位ID
     */
    private String managementOrgId;
    /**
     * 铺货单位名称
     */
    private String managementOrgName;
    /**
     * 商品重量
     */
    private BigDecimal goodsWeight;
    /**
     * 商品总重量
     */
    private BigDecimal totalGoodsWeight;
    /**
     * 加价比例
     */
    private String addPriceRatio;
    /**
     * 是否加价
     */
    private String isAddPrice;
    /**
     * 是否加价
     */
    private String isAddPriceStr;
    /**
     * 已发货明细销售金额
     */
    private BigDecimal totalSendGoodsSaleFee;

    /**
     * 已发货明细采购金额
     */
    private BigDecimal totalSendGoodsPurchaseFee;
    /**
     * 电商预订单下单失败原因
     */
    private String failReason;

    /**
     * 调价前销售单价
     */
    private BigDecimal adjustSalePrice;

    /**
     * 销售单价调价幅度
     */
    private BigDecimal adjustSalePriceRange;

    /**
     * 销售价调价原因
     */
    private String adjustSaleReason;

    /**
     * 调价前采购单价
     */
    private BigDecimal adjustPurchasePrice;

    /**
     * 采购单价调价幅度
     */
    private BigDecimal adjustPurchasePriceRange;

    /**
     * 采购价调价原因
     */
    private String adjustPurchaseReason;
    /**
     * 调价前商品销售总价
     */
    private BigDecimal adjustSaleFee;
    /**
     * 调价前商品采购总价
     */
    private BigDecimal adjustPurchaseFee;
    /**
     * 成交服务费类型 1账期折扣 2返点
     */
    private Integer tranServFeeType;

    /**
     * 成交服务费比率
     */
    private BigDecimal tranServFeeRatio;

    /**
     * 四级类目编码
     */
    private String l4Catalog;

    /**
     * 四级类目名称
     */
    private String l4CatalogName;
}
